@@ -574,7 +574,7 @@ pub(crate) struct GenresIter<'a> {
 }
 
 impl<'a> GenresIter<'a> {
-	pub fn new(value: &'a str, preserve_indexes: bool) -> GenresIter<'_> {
+	pub fn new(value: &'a str, preserve_indexes: bool) -> GenresIter<'a> {
 		GenresIter {
 			value,
 			pos: 0,
@@ -1379,7 +1379,6 @@ impl MergeTag for SplitTagRemainder {
 			&ItemKey::Composer,
 			&ItemKey::Conductor,
 			&ItemKey::Writer,
-			&ItemKey::Director,
 			&ItemKey::Lyricist,
 			&ItemKey::MusicianCredits,
 			&ItemKey::InternetRadioStationName,
@@ -1402,6 +1401,23 @@ impl MergeTag for SplitTagRemainder {
 			}
 		}
 
+		// Multi-valued TXXX key-to-frame mappings
+		for item_key in [
+			&ItemKey::TrackArtists,
+			&ItemKey::Director,
+			&ItemKey::CatalogNumber,
+		] {
+			let frame_id = item_key
+				.map_key(TagType::Id3v2, false)
+				.expect("valid frame id");
+			if let Some(text) = join_text_items(&mut tag, [item_key]) {
+				let frame = new_user_text_frame(String::from(frame_id), text);
+				// Optimization: No duplicate checking according to the preconditions
+				debug_assert!(!merged.frames.contains(&frame));
+				merged.frames.push(frame);
+			}
+		}
+
 		// Multi-valued Label/Publisher key-to-frame mapping
 		{
 			let frame_id = ItemKey::Label
@@ -1507,6 +1523,7 @@ impl MergeTag for SplitTagRemainder {
 			));
 		}
 
+		// iTunes advisory rating
 		'rate: {
 			if let Some(advisory_rating) = tag.take_strings(&ItemKey::ParentalAdvisory).next() {
 				let Ok(rating) = advisory_rating.parse::<u8>() else {
